function v=compute_ekman_surge_aen(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_aen
% Script automatically generated by fit_ekman_surge_aen.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.84154
% RMSE  = 0.12185
% MEAN  = 0.40149
% RANGE = 0.030222 - 1.254

beta( 1 )= 2.2199e-06 ;
beta( 2 )= 3.8759e-02 ;
beta( 3 )= 5.1152e-01 ;
beta( 4 )= -3.7435e-01 ;
beta( 5 )= -5.5231e+01 ;
beta( 6 )= 8.0221e-01 ;
beta( 7 )= 3.5943e-01 ;
beta( 8 )= 8.3682e-01 ;
beta( 9 )= -4.1703e-01 ;
beta( 10 )= -2.0212e-01 ;
beta( 11 )= 2.1994e-01 ;

v=beta(1) * exp(-a/beta(2)) .* w.^beta(3) .* (1+beta(4)*sin((phi-beta(5))*pi/180))  .* vmax.^beta(6)  .* r35.^beta(7)  .* lat.^beta(8)  .* n.^beta(9) .* vt.^beta(10)  .* rmax.^beta(11);
